* Eugenia Oshurko @ Blue Brain Project, EPFL
* Mohameth François Sy @ Blue Brain Project, EPFL
* Pierre-Alexandre Fonta @ Blue Brain Project, EPFL
* Anna-Kristin Kaufmann @ Blue Brain Project, EPFL
* Lurie Jonathan Raël @ Blue Brain Project, EPFL
